% -*-trale-prolog-*-
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%   $RCSfile: theory.pl,v $
%%  $Revision: 1.13 $
%%      $Date: 2007/03/05 11:26:29 $
%%     Author: Stefan Mueller (Stefan.Mueller@cl.uni-bremen.de)
%%    Purpose: Eine kleine Spielzeuggrammatik für die Lehre
%%   Language: Trale
%      System: TRALE 2.7.5 (release ) under Sicstus 3.10.1
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

:- (environ('TRALE_UNICODE', true);
    format(user_error,"~n~n**ERROR: Please start trale with the option `-u' to enable unicode support, which is needed for this grammar.~n~n~n",[]),
    abort).

% für [incr TSDB()]
grammar_version('Lehrbuchgrammatik Kapitel 16').


% feature hiding and ordering
hidden_feat(dtrs).      % hide the dtrs attribute (shown by tree)

% Die sind in den Bäumen enthalten, deshalb werden sie hier ausgeblendet.
hidden_feat(non_head_dtrs).
hidden_feat(head_dtr).

% ein technisches Merkmal, das wegen der Arbeitsweise der Lexikonregeln gebraucht wird.
hidden_feat(affix_).

% only for demos
/*
hidden_feat(spr).
hidden_feat(nonloc).
hidden_feat(zu).
hidden_feat(flip).
hidden_feat(dsl).
hidden_feat(initial).
*/

% Binäres Merkmal, das aus Effizenzgründen verwendet wird.
% Sieht nicht gut aus in Demos ... =;-)
hidden_feat(trace).



>>> phon.        % phon shall be shown first
phon   <<< synsem.
synsem <<< head_dtr.

head <<< subcat.

loc <<< nonloc.
nonloc <<< lex.
%<<<(lex, max_).

% use ghostview for drawing signatures
graphviz_option(ps,gv).
%graphviz_option(svg,squiggle).

% Load phonology and tree output

:- [trale_home(tree_extensions)].


:- chart_display.

:- nochart_debug.  % this helps if somebody interrupted during chart debugging and the
                   % flag is still set to 'on'.

:- german.

:- notcl_warnings.  % on = output of warnings in a TCL window, off = output to console

:- hrp.  % use grisu for rules

%:- nofs. % do not print feature structures after parsing

root_symbol(@root).
decl_symbol(@decl).
que_symbol(@interrog).

% load tokenization rules for parsing ordinary strings and atoms
:- ['../Gemeinsames/tokenization'].

% specify signature file
signature(signature).

% load lexicon
:- [lexicon].


% load lexical macros
:- [le_macros].
:- [flex_macros].


% load suffixes for inflection
:- [suffixes].

% load lexical rules
:- [lexrules].

% load lexical rule for multiple frontings
%:- ['mehrfache-vorfeldbesetzung'].

% load phrase structure rules
:- [rules].

:- [oberfeldumstellung].

% load phrase structure macros
:- [syntax].

% load some constraints that are not linguistically necessary,
% but good for performance
:- [speed].

% load relational constraints for rules
:- [constraints].

% load a test sequence
:- [test_items].

% load a sequence that is executed after the grammar is loaded
:- ['../Gemeinsames/common.pl'].

%phenomenon('Kapitel 13: Kongruenz').

examples(['  Er scheint zu schlafen.',
          '  Er sieht es schlafen.',
          '  Er versucht, das Lied zu singen.',
          '  Er verspricht ihm, das Lied zu singen.',
          '  Er zwingt ihn, das Lied zu singen.',
          '  daß ihn der Mann zu lesen versucht']).


